@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2008, 2009, 2010, 2012 Red Hat, Inc.
+## Copyright (C) 2008, 2009, 2010, 2012, 2014 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -31,6 +31,7 @@ class PhysicalDevice:
         self.devices = None
         self._network_host = None
         self.dnssd_hostname = None
+        self._cupsserver = False
         self.add_device (device)
         self._user_data = {}
         self._ppdippstr = ppdippstr.backends
@@ -131,6 +132,16 @@ class PhysicalDevice:
         if device.type == "socket":
             # Remove default port to more easily find duplicate URIs
             device.uri = device.uri.replace (":9100", "")
+        if (device.uri.startswith('ipp:') and \
+            device.uri.find('/printers/') != -1) or \
+           ((device.uri.startswith('dnssd:') or \
+             device.uri.startswith('mdns:')) and \
+            device.uri.endswith('/cups')):
+            # CUPS server
+            self._cupsserver = True
+        elif self._cupsserver:
+            # Non-CUPS queue on a CUPS server, drop this one
+            return
         for d in self.devices:
             if d.uri == device.uri:
                 return
@@ -147,11 +158,17 @@ class PhysicalDevice:
                 self.dnssd_hostname = dnssdhost;
 
         if (hasattr (device, 'address') and self._network_host == None):
-            if device.address:
-                self._network_host = device.address
+            address = device.address
+            if address:
+                if type (address) == unicode:
+                    address = address.encode ('utf-8')
+                self._network_host = address
         if (hasattr (device, 'hostname') and self.dnssd_hostname == None):
-            if device.hostname:
-                self.dnssd_hostname = device.hostname
+            hostname = device.hostname
+            if hostname:
+                if type (hostname) == unicode:
+                    hostname = hostname.encode ('utf-8')
+                self.dnssd_hostname = hostname
 
     def get_devices (self):
         return self.devices
