@@ -459,12 +459,12 @@ class _IPPAuthOperation:
 
         # If we've previously prompted, explain why we're prompting again.
         if self._dialog_shown:
-            d = Gtk.MessageDialog (self._conn.parent,
-                                   Gtk.DialogFlags.MODAL |
-                                   Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                   Gtk.MessageType.ERROR,
-                                   Gtk.ButtonsType.CLOSE,
-                                   _("Not authorized"))
+            d = Gtk.MessageDialog (parent=self._conn.parent,
+                                   flags=Gtk.DialogFlags.MODAL |
+                                         Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                   message_type=Gtk.MessageType.ERROR,
+                                   buttons=Gtk.ButtonsType.CLOSE,
+                                   message_format=_("Not authorized"))
             d.format_secondary_text (_("The password may be incorrect."))
             d.run ()
             d.destroy ()
@@ -480,11 +480,11 @@ class _IPPAuthOperation:
             d = authconn.AuthDialog (title=title,
                                      parent=conn.parent)
 
-        d.set_prompt (prompt)
+        d.set_prompt ('')
         if self._user == None:
             self._user = cups.getUser()
-        d.set_auth_info ([self._user, ''])
-        d.field_grab_focus ('password')
+        d.set_auth_info (['', ''])
+        d.field_grab_focus ('username')
         d.set_keep_above (True)
         d.show_all ()
         d.connect ("response", self._on_auth_dialog_response)
@@ -555,12 +555,12 @@ class _IPPAuthOperation:
         else:
             msg = _("CUPS server error (%s)") % op
 
-        d = Gtk.MessageDialog (self._conn.parent,
-                               Gtk.DialogFlags.MODAL |
-                               Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                               Gtk.MessageType.ERROR,
-                               Gtk.ButtonsType.NONE,
-                               msg)
+        d = Gtk.MessageDialog (parent=self._conn.parent,
+                               flags=Gtk.DialogFlags.MODAL |
+                                     Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                               message_type=Gtk.MessageType.ERROR,
+                               buttons=Gtk.ButtonsType.NONE,
+                               message_format=msg)
 
         if self._client_fn == None and type (exc) == RuntimeError:
             # This was a connection failure.
@@ -657,17 +657,16 @@ class IPPAuthConnection(IPPConnection):
 if __name__ == "__main__":
     # Demo
     set_debugging (True)
-    GObject.threads_init ()
     class UI:
         def __init__ (self):
             w = Gtk.Window ()
             w.connect ("destroy", self.destroy)
-            b = Gtk.Button ("Connect")
+            b = Gtk.Button.new_with_label ("Connect")
             b.connect ("clicked", self.connect_clicked)
             vbox = Gtk.VBox ()
             vbox.pack_start (b, False, False, 0)
             w.add (vbox)
-            self.get_devices_button = Gtk.Button ("Get Devices")
+            self.get_devices_button = Gtk.Button.new_with_label ("Get Devices")
             self.get_devices_button.connect ("clicked", self.get_devices)
             self.get_devices_button.set_sensitive (False)
             vbox.pack_start (self.get_devices_button, False, False, 0)
