@@ -576,7 +576,6 @@ class PK1Connection:
 
 if __name__ == '__main__':
     from gi.repository import GObject
-    GObject.threads_init ()
     from debug import set_debugging
     set_debugging (True)
     class UI:
@@ -584,25 +583,25 @@ if __name__ == '__main__':
             w = Gtk.Window ()
             v = Gtk.VBox ()
             w.add (v)
-            b = Gtk.Button ("Go")
+            b = Gtk.Button.new_with_label ("Go")
             v.pack_start (b, False, False, 0)
             b.connect ("clicked", self.button_clicked)
-            b = Gtk.Button ("Fetch")
+            b = Gtk.Button.new_with_label ("Fetch")
             v.pack_start (b, False, False, 0)
             b.connect ("clicked", self.fetch_clicked)
             b.set_sensitive (False)
             self.fetch_button = b
-            b = Gtk.Button ("Cancel job")
+            b = Gtk.Button.new_with_label ("Cancel job")
             v.pack_start (b, False, False, 0)
             b.connect ("clicked", self.cancel_clicked)
             b.set_sensitive (False)
             self.cancel_button = b
-            b = Gtk.Button ("Get file")
+            b = Gtk.Button.new_with_label ("Get file")
             v.pack_start (b, False, False, 0)
             b.connect ("clicked", self.get_file_clicked)
             b.set_sensitive (False)
             self.get_file_button = b
-            b = Gtk.Button ("Something harmless")
+            b = Gtk.Button.new_with_label ("Something harmless")
             v.pack_start (b, False, False, 0)
             b.connect ("clicked", self.harmless_clicked)
             b.set_sensitive (False)
