@@ -26,7 +26,6 @@ import cupshelpers
 from cupshelpers.ppds import PPDs, ppdMakeModelSplit
 import sys
 
-cups.setUser ('root')
 c = cups.Connection ()
 
 devices = None
@@ -70,6 +69,9 @@ if devices == None:
     if not SPECIFIC_URI:
         print "Examining connected devices"
 
+    cups.setUser ('root')
+    c = cups.Connection ()
+
     try:
         if SPECIFIC_URI:
             scheme = str (SPECIFIC_URI.split (":", 1)[0])
@@ -82,7 +84,7 @@ if devices == None:
             print "Run this as root to examine IDs from attached devices."
             sys.exit (1)
 
-        if e == cups.IPP_NOT_AUTHORIZED:
+        if e in (cups.IPP_NOT_AUTHORIZED, cups.IPP_AUTHENTICATION_CANCELED):
             print "Not authorized."
             sys.exit (1)
 
