@@ -1,6 +1,6 @@
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008 Red Hat, Inc.
+## Copyright (C) 2006, 2007, 2008, 2014 Red Hat, Inc.
 ## Copyright (C) 2006, 2007 Florian Festi <ffesti@redhat.com>
 ## Copyright (C) 2006, 2007, 2008 Tim Waugh <twaugh@redhat.com>
 
@@ -22,5 +22,8 @@ prefix="/usr/local"
 datadir="/usr/local/share"
 localedir="/usr/local/share/locale"
 pkgdatadir="/usr/local/share/system-config-printer"
-VERSION="1.4.3"
+VERSION="1.4.6"
 PACKAGE="system-config-printer"
+DOWNLOADABLE_ONLYPPD=True
+DOWNLOADABLE_ONLYFREE=True
+DOWNLOADABLE_PKG_ONLYSIGNED=True
