@@ -2,7 +2,7 @@
 
 ## system-config-printer
 
-## Copyright (C) 2008, 2011 Red Hat, Inc.
+## Copyright (C) 2008, 2011, 2014 Red Hat, Inc.
 ## Copyright (C) 2008 Till Kamppeter <till.kamppeter@gmail.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@ import pycurl, urllib, platform, threading, tempfile, traceback
 import os, sys
 from xml.etree.ElementTree import XML
 from . import Device
+from . import _debugprint
 
 __all__ = ['OpenPrinting']
 
@@ -45,6 +46,10 @@ class _QueryThread (threading.Thread):
         self.result = ""
 
         self.setDaemon (True)
+        _debugprint ("+%s" % self)
+
+    def __del__ (self):
+        _debugprint ("-%s" % self)
 
     def run (self):
 
@@ -82,6 +87,7 @@ class _QueryThread (threading.Thread):
             self.result = sys.exc_info ()
             if status == None: status = 0
 
+        _debugprint ("%s: query complete" % self)
         if self.callback != None:
             self.callback (status, self.user_data, self.result)
 
@@ -96,7 +102,7 @@ class OpenPrinting:
             import locale
             try:
                 language = locale.getlocale(locale.LC_MESSAGES)
-            except locale.Error, e:
+            except locale.Error:
                 language = 'C'
         self.language = language
 
@@ -107,6 +113,11 @@ class OpenPrinting:
         # config file
         self.onlyfree = 1
         self.onlymanufacturer = 0
+        _debugprint ("OpenPrinting: Init %s %s %s" % (self.language, self.onlyfree, self.onlymanufacturer))
+        _debugprint ("+%s" % self)
+
+    def __del__ (self):
+        _debugprint ("-%s" % self)
 
     def cancelOperation(self, handle):
         """
@@ -176,6 +187,7 @@ class OpenPrinting:
                 status = 1
                 printers = sys.exc_info ()
 
+            _debugprint ("searchPrinters/parse_result: OpenPrinting entries: %s" % repr(printers))
             try:
                 callback (status, user_data, printers)
             except:
@@ -192,6 +204,7 @@ class OpenPrinting:
         params = { 'type': 'printers',
                    'printer': searchterm,
                    'format': 'xml' }
+        _debugprint ("searchPrinters: Querying OpenPrinting: %s" % repr(params))
         return self.webQuery(params, parse_result, (callback, user_data))
 
     def listDrivers(self, model, callback, user_data=None, extra_options=None):
@@ -355,6 +368,7 @@ class OpenPrinting:
                         dict['ppds'] = ppds
 
                     drivers[id] = dict
+                    _debugprint ("listDrivers/parse_result: OpenPrinting entries: %s" % repr(drivers))
                 callback (0, user_data, drivers)
             except:
                 callback (1, user_data, sys.exc_info ())
@@ -374,6 +388,7 @@ class OpenPrinting:
                    'format': 'xml'}
         if extra_options:
             params.update(extra_options)
+        _debugprint ("listDrivers: Querying OpenPrinting: %s" % repr(params))
         return self.webQuery(params, parse_result, (callback, user_data))
 
 def _simple_gui ():
@@ -384,12 +399,11 @@ def _simple_gui ():
     class QueryApp:
         def __init__(self):
             self.openprinting = OpenPrinting()
-            self.main = Gtk.Dialog ("OpenPrinting query application",
-                                    None,
-                                    Gtk.DialogFlags.MODAL,
-                                    (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE,
-                                     "Search", 10,
-                                     "List", 20))
+            self.main = Gtk.Dialog (title="OpenPrinting query application",
+                                    transient_for=None, modal=True)
+            self.main.add_buttons (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE,
+                                   "Search", 10,
+                                   "List", 20)
             self.main.set_border_width (6)
             self.main.vbox.set_spacing (2)
             vbox = Gtk.VBox.new (False, 6)
