@@ -2,7 +2,7 @@
 
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Red Hat, Inc.
+## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2014 Red Hat, Inc.
 ## Copyright (C) 2006 Florian Festi <ffesti@redhat.com>
 ## Copyright (C) 2006, 2007, 2008, 2009 Tim Waugh <twaugh@redhat.com>
 
@@ -70,9 +70,9 @@ _MFR_BY_RANGE = [
     ("KONICA MINOLTA", re.compile("magicolor"
                                   "|pageworks"
                                   "|pagepro")),
-    ("Kyocera Mita", re.compile("fs-"
-                                "|km-"
-                                "|taskalfa")),
+    ("Kyocera", re.compile("fs-"
+                           "|km-"
+                           "|taskalfa")),
     ("Ricoh", re.compile("aficio")),
     ("Oce", re.compile("varioprint")),
     ("Oki", re.compile("okipage|microline"))
@@ -166,11 +166,14 @@ def ppdMakeModelSplit (ppd_make_and_model):
         make = "Lexmark"
         model = ppd_make_and_model[22:]
     elif l.startswith ("kyocera mita "):
-        make = "Kyocera Mita"
+        make = "Kyocera"
         model = ppd_make_and_model[13:]
     elif l.startswith ("kyocera "):
-        make = "Kyocera Mita"
+        make = "Kyocera"
         model = ppd_make_and_model[8:]
+    elif l.startswith ("fuji xerox "):
+        make = "Fuji Xerox"
+        model = ppd_make_and_model[11:]
 
     # Finally, take the first word as the name of the manufacturer.
     else:
@@ -423,7 +426,7 @@ class PPDs:
             models_list = self.makes[make].keys ()
         except KeyError:
             return []
-        models_list.sort (key=lambda x: x.lower(), cmp=cups.modelSort)
+        models_list.sort (key=lambda x: normalize (x), cmp=cups.modelSort)
         return models_list
 
     def getInfoFromModel (self, make, model):
