@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2010, 2011, 2012 Red Hat, Inc.
+## Copyright (C) 2010, 2011, 2012, 2013, 2014 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -19,6 +19,7 @@
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import dbus, re
+import urlparse
 from debug import *
 
 class DNSSDHostNamesResolver:
@@ -33,10 +34,6 @@ class DNSSDHostNamesResolver:
 
     def resolve (self, reply_handler):
 
-        def expandhex (searchres):
-            expr = searchres.group(0)
-            return chr(int(expr[1:], 16))
-
         self._reply_handler = reply_handler
 
         bus = dbus.SystemBus ()
@@ -53,21 +50,20 @@ class DNSSDHostNamesResolver:
 
             # We need to resolve the DNS-SD hostname in order to
             # compare with other network devices.
-            p = uri[8:].find ("/")
-            if p == -1:
-                hostname = uri[8:]
-            else:
-                hostname = uri[8:8+p]
-
-            hostname = hostname.encode('utf-8')
-            hostname = re.sub("%(?i)[\dabcdef]{2}", expandhex, hostname)
+            try:
+                uri = str (uri)
+            except:
+                pass
 
+            result = urlparse.urlparse (str (uri))
+            hostname = result.netloc
             elements = hostname.rsplit (".", 3)
             if len (elements) != 4:
                 self._resolved ()
                 continue
 
             name, stype, protocol, domain = elements
+            name = urlparse.unquote (name)
             stype += "." + protocol #  e.g. _printer._tcp
 
             try:
@@ -82,8 +78,8 @@ class DNSSDHostNamesResolver:
                                         reply_handler=self._reply,
                                         error_handler=lambda e:
                                             self._error (uri, e))
-            except dbus.DBusException, e:
-                debugprint ("Failed to resolve address: %s" % e)
+            except dbus.DBusException as e:
+                debugprint ("Failed to resolve address: %s" % repr (e))
                 self._resolved ()
 
     def _resolved (self):
@@ -107,7 +103,7 @@ class DNSSDHostNamesResolver:
         self._resolved ()
 
     def _error (self, uri, error):
-        debugprint ("Error resolving %s: %s" % (uri, error))
+        debugprint ("Error resolving %s: %s" % (uri, repr (error)))
         self._resolved ()
 
 if __name__ == '__main__':
