@@ -1,5 +1,5 @@
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 ##  Jiri Popelka <jpopelka@redhat.com>
@@ -196,11 +196,10 @@ class CancelJobsOperation(GObject.GObject):
                 dialog_title = _("Cancel Job")
                 dialog_label = _("Do you really want to cancel this job?")
 
-        dialog = Gtk.Dialog (dialog_title, parent,
-                             Gtk.DialogFlags.MODAL |
-                             Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                             (_("Keep Printing"), Gtk.ResponseType.NO,
-                              dialog_title, Gtk.ResponseType.YES))
+        dialog = Gtk.Dialog (title=dialog_title, transient_for=parent,
+                             modal=True, destroy_with_parent=True)
+        dialog.add_buttons (_("Keep Printing"), Gtk.ResponseType.NO,
+                            dialog_title, Gtk.ResponseType.YES)
         dialog.set_default_response (Gtk.ResponseType.NO)
         dialog.set_border_width (6)
         dialog.set_resizable (False)
@@ -363,7 +362,7 @@ class JobViewer (GtkGUI):
 
                          domain=config.PACKAGE)
 
-        job_action_group = Gtk.ActionGroup ("JobActionGroup")
+        job_action_group = Gtk.ActionGroup (name="JobActionGroup")
         job_action_group.add_actions ([
                 ("cancel-job", Gtk.STOCK_CANCEL, _("_Cancel"), None,
                  _("Cancel selected jobs"), self.on_job_cancel_activate),
@@ -589,7 +588,7 @@ class JobViewer (GtkGUI):
         self.JobsAttributesWindow.connect("delete_event",
                                           self.job_attributes_on_delete_event)
         self.JobsAttributesWindow.add_accel_group (self.job_ui_manager.get_accel_group ())
-        attrs_action_group = Gtk.ActionGroup ("AttrsActionGroup")
+        attrs_action_group = Gtk.ActionGroup (name="AttrsActionGroup")
         attrs_action_group.add_actions ([
                 ("close", Gtk.STOCK_CLOSE, None, "<ctrl>w",
                  _("Close this window"), self.job_attributes_on_delete_event)
@@ -906,52 +905,70 @@ class JobViewer (GtkGUI):
         self.treeview.queue_draw ()
 
         # Check whether authentication is required.
-        if self.applet:
-            job_requires_auth = (s == cups.IPP_JOB_HELD and
-                                 data.get ('job-hold-until', 'none') ==
-                                 'auth-info-required')
+        job_requires_auth = (s == cups.IPP_JOB_HELD and
+                             data.get ('job-hold-until', 'none') ==
+                             'auth-info-required')
+        if job_requires_auth:
+            # Try to get the authentication information. If we are not
+            # running as an applet just try to get the information silently
+            # and not prompt the user.
+            self.get_authentication (job, data.get ('device-uri'),
+                                     data.get ('job-printer-uri'),
+                                     data.get ('auth-info-required', []),
+                                     self.applet)
+        self.update_sensitivity ()
 
-            if (job_requires_auth and
-                not self.auth_info_dialogs.has_key (job)):
-                try:
-                    cups.require ("1.9.37")
-                except:
-                    debugprint ("Authentication required but "
-                                "authenticateJob() not available")
-                    return
+    def get_authentication (self, job, device_uri, printer_uri,
+                            auth_info_required, show_dialog):
+        # Check if we have requested authentication for this job already
+        if not self.auth_info_dialogs.has_key (job):
+            try:
+                cups.require ("1.9.37")
+            except:
+                debugprint ("Authentication required but "
+                            "authenticateJob() not available")
+                return
 
-                # Find out which auth-info is required.
-                try_keyring = USE_KEYRING
-                keyring_attrs = dict()
-                auth_info = None
-                if try_keyring and 'password' in auth_info_required:
-                    auth_info_required = data.get ('auth-info-required', [])
-                    device_uri = data.get ("device-uri")
-                    (scheme, rest) = urllib.splittype (device_uri)
-                    if scheme == 'smb':
-                        uri = smburi.SMBURI (uri=device_uri)
-                        (group, server, share,
-                         user, password) = uri.separate ()
-                        keyring_attrs["domain"] = str (group)
+            # Find out which auth-info is required.
+            try_keyring = USE_KEYRING
+            informational_attrs = dict()
+            auth_info = None
+            if try_keyring and 'password' in auth_info_required:
+                (scheme, rest) = urllib.splittype (device_uri)
+                if scheme == 'smb':
+                    uri = smburi.SMBURI (uri=device_uri)
+                    (group, server, share,
+                     user, password) = uri.separate ()
+                    informational_attrs["domain"] = str (group)
+                else:
+                    (serverport, rest) = urllib.splithost (rest)
+                    if serverport == None:
+                        server = None
                     else:
-                        (serverport, rest) = urllib.splithost (rest)
-                        if serverport == None:
-                            server = None
-                        else:
-                            (server, port) = urllib.splitnport (serverport)
+                        (server, port) = urllib.splitnport (serverport)
 
-                    if scheme == None or server == None:
-                        try_keyring = False
-                    else:
-                        keyring_attrs.update ({ "server": str (server.lower ()),
-                                                "protocol": str (scheme)})
-
-                if job in self.authenticated_jobs:
-                    # We've already tried to authenticate this job before.
+                if scheme == None or server == None:
                     try_keyring = False
+                else:
+                    informational_attrs.update ({ "server": str (server.lower ()),
+                                                 "protocol": str (scheme)})
 
-                if try_keyring and 'password' in auth_info_required:
-                    type = GnomeKeyring.ItemType.NETWORK_PASSWORD
+            if job in self.authenticated_jobs:
+                # We've already tried to authenticate this job before.
+                try_keyring = False
+
+            # To increase compatibility and resolve problems with
+            # multiple printers on one host we use the printers URI
+            # as the identifying attribute. Versions <= 1.4.4 used
+            # a combination of domain / server / protocol instead.
+            # The old attributes are still used as a fallback for identifying
+            # the secret but are otherwise only informational.
+            identifying_attrs = { "uri": str (printer_uri) }
+
+            if try_keyring and 'password' in auth_info_required:
+                type = GnomeKeyring.ItemType.NETWORK_PASSWORD
+
+                for keyring_attrs in [identifying_attrs, informational_attrs]:
                     attrs = GnomeKeyring.Attribute.list_new ()
                     for key, val in keyring_attrs.iteritems ():
                         GnomeKeyring.Attribute.list_append_string (attrs,
@@ -977,41 +994,42 @@ class JobViewer (GtkGUI):
 
                         ind = auth_info_required.index ('password')
                         auth_info[ind] = items[0].secret
-                    else:
-                        debugprint ("gnomekeyring: look-up result %s" %
-                                    repr (result))
+                        break
+                else:
+                    debugprint ("Failed to find secret in keyring.")
 
-                if try_keyring and c == None:
-                    try:
-                        c = authconn.Connection (self.JobsWindow,
-                                                 host=self.host,
-                                                 port=self.port,
-                                                 encryption=self.encryption)
-                    except RuntimeError:
-                        try_keyring = False
+            if try_keyring:
+                try:
+                    c = authconn.Connection (self.JobsWindow,
+                                             host=self.host,
+                                             port=self.port,
+                                             encryption=self.encryption)
+                except RuntimeError:
+                    try_keyring = False
 
-                if try_keyring and auth_info != None:
-                    try:
-                        c._begin_operation (_("authenticating job"))
-                        c.authenticateJob (job, auth_info)
-                        c._end_operation ()
-                        self.update_monitor ()
-                        debugprint ("Automatically authenticated job %d" % job)
-                        self.authenticated_jobs.add (job)
-                        return
-                    except cups.IPPError:
-                        c._end_operation ()
-                        nonfatalException ()
-                        return
-                    except:
-                        c._end_operation ()
-                        nonfatalException ()
+            if try_keyring and auth_info != None:
+                try:
+                    c._begin_operation (_("authenticating job"))
+                    c.authenticateJob (job, auth_info)
+                    c._end_operation ()
+                    self.update_monitor ()
+                    debugprint ("Automatically authenticated job %d" % job)
+                    self.authenticated_jobs.add (job)
+                    return
+                except cups.IPPError:
+                    c._end_operation ()
+                    nonfatalException ()
+                    return
+                except:
+                    c._end_operation ()
+                    nonfatalException ()
 
-                if data.has_key ('auth-info-required'):
-                    username = pwd.getpwuid (os.getuid ())[0]
-                    keyring_attrs["user"] = str (username)
-                    self.display_auth_info_dialog (job, keyring_attrs)
-        self.update_sensitivity ()
+            if auth_info_required and show_dialog:
+                username = pwd.getpwuid (os.getuid ())[0]
+                keyring_attrs = informational_attrs.copy()
+                keyring_attrs.update(identifying_attrs)
+                keyring_attrs["user"] = str (username)
+                self.display_auth_info_dialog (job, keyring_attrs)
 
     def display_auth_info_dialog (self, job, keyring_attrs=None):
         data = self.jobs[job]
@@ -1163,7 +1181,7 @@ class JobViewer (GtkGUI):
             Gtk.main_iteration ()
 
     def on_treeview_popup_menu (self, treeview):
-        event = Gdk.Event (Gdk.NOTHING)
+        event = Gdk.Event (Gdk.EventType.NOTHING)
         self.show_treeview_popup_menu (treeview, event, 0)
 
     def on_treeview_button_release_event(self, treeview, event):
@@ -1413,7 +1431,11 @@ class JobViewer (GtkGUI):
             try:
                 attrs=c.getJobAttributes(jobid)
                 printer_uri=attrs['job-printer-uri']
-                document_count=attrs.get ('document-count', 0)
+                try:
+                    document_count = attrs['number-of-documents']
+                except KeyError:
+                    document_count = attrs.get ('document-count', 0)
+
                 for document_number in range(1, document_count+1):
                     document=c.getDocument(printer_uri, jobid, document_number)
                     tempfile = document.get('file')
@@ -1433,11 +1455,12 @@ class JobViewer (GtkGUI):
                             name = name + format.replace('application/', '.')
 
                     if tempfile != None:
-                        dialog = Gtk.FileChooserDialog (_("Save File"),
-                                                        self.JobsWindow,
-                                                  Gtk.FileChooserAction.SAVE,
-                                        (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-                                         Gtk.STOCK_SAVE, Gtk.ResponseType.OK))
+                        dialog = Gtk.FileChooserDialog (title=_("Save File"),
+                                            transient_for=self.JobsWindow,
+                                            action=Gtk.FileChooserAction.SAVE)
+                        dialog.add_buttons (
+                                    Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                                    Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
                         dialog.set_current_name(name)
                         dialog.set_do_overwrite_confirmation(True)
 
@@ -1485,8 +1508,32 @@ class JobViewer (GtkGUI):
         self.update_monitor ()
 
     def on_job_authenticate_activate(self, menuitem):
+        try:
+            c = cups.Connection (host=self.host,
+                                 port=self.port,
+                                 encryption=self.encryption)
+        except RuntimeError:
+            return False
+
+        jattrs_req = ['job-printer-uri']
+        pattrs_req = ['auth-info-required', 'device-uri']
+
         for jobid in self.jobids:
-            self.display_auth_info_dialog (jobid)
+            # Get the requried attributes for this job
+            jattrs = c.getJobAttributes (jobid,
+                                         requested_attributes=jattrs_req)
+            uri = jattrs.get ('job-printer-uri')
+            pattrs = c.getPrinterAttributes (uri = uri,
+                                             requested_attributes=pattrs_req)
+            try:
+                auth_info_required = pattrs['auth-info-required']
+            except KeyError:
+                debugprint ("No auth-info-required attribute; "
+                            "guessing instead")
+                auth_info_required = ['username', 'password']
+
+            self.get_authentication (jobid, pattrs.get ('device-uri'),
+                                     uri, auth_info_required, True)
 
     def on_refresh_clicked(self, toolbutton):
         self.monitor.refresh ()
@@ -1556,6 +1603,8 @@ class JobViewer (GtkGUI):
             for name, value in attrs.iteritems():
                 if name in ['job-id', 'job-printer-up-time']:
                     continue
+                if isinstance(value, unicode): # TODO: remove this after merging python3 branch
+                    value.encode('utf-8')
                 attr_store.append([name, str(value)])
 
     def job_is_active (self, jobdata):
@@ -1996,9 +2045,10 @@ class JobViewer (GtkGUI):
             if may_be_problem:
                 debugprint ("Problem detected")
                 self.toggle_window_display (None, force_show=True)
-                dialog = Gtk.Dialog (_("Print Error"), self.JobsWindow, 0,
-                                     (_("_Diagnose"), Gtk.ResponseType.NO,
-                                        Gtk.STOCK_OK, Gtk.ResponseType.OK))
+                dialog = Gtk.Dialog (title=_("Print Error"),
+                                     transient_for=self.JobsWindow)
+                dialog.add_buttons (_("_Diagnose"), Gtk.ResponseType.NO,
+                                    Gtk.STOCK_OK, Gtk.ResponseType.OK)
                 dialog.set_default_response (Gtk.ResponseType.OK)
                 dialog.set_border_width (6)
                 dialog.set_resizable (False)
@@ -2200,18 +2250,30 @@ class JobViewer (GtkGUI):
 
     def _set_job_user_text (self, column, cell, model, iter, *data):
         jobid = model.get_value (iter, 0)
-        job = self.jobs[jobid]
+        try:
+            job = self.jobs[jobid]
+        except KeyError:
+            return
+
         cell.set_property("text", job.get ('job-originating-user-name',
                                            _("Unknown")))
 
     def _set_job_document_text (self, column, cell, model, iter, *data):
         jobid = model.get_value (iter, 0)
-        job = self.jobs[jobid]
+        try:
+            job = self.jobs[jobid]
+        except KeyError:
+            return
+
         cell.set_property("text", job.get('job-name', _("Unknown")))
 
     def _set_job_printer_text (self, column, cell, model, iter, *data):
         jobid = model.get_value (iter, 0)
-        reasons = self.jobs[jobid].get('job-state-reasons')
+        try:
+            reasons = self.jobs[jobid].get('job-state-reasons')
+        except KeyError:
+            return
+
         if reasons == 'printer-stopped':
             reason = ' - ' + _("disabled")
         else:
@@ -2220,14 +2282,22 @@ class JobViewer (GtkGUI):
 
     def _set_job_size_text (self, column, cell, model, iter, *data):
         jobid = model.get_value (iter, 0)
-        job = self.jobs[jobid]
+        try:
+            job = self.jobs[jobid]
+        except KeyError:
+            return
+
         size = _("Unknown")
         if job.has_key ('job-k-octets'):
             size = str (job['job-k-octets']) + 'k'
         cell.set_property("text", size)
 
     def _find_job_state_text (self, job):
-        data = self.jobs[job]
+        try:
+            data = self.jobs[job]
+        except KeyError:
+            return
+
         jstate = data.get ('job-state', cups.IPP_JOB_PROCESSING)
         s = int (jstate)
         job_requires_auth = (s == cups.IPP_JOB_HELD and
@@ -2307,7 +2377,11 @@ class JobViewer (GtkGUI):
 
     def _set_job_status_icon (self, column, cell, model, iter, *data):
         jobid = model.get_value (iter, 0)
-        data = self.jobs[jobid]
+        try:
+            data = self.jobs[jobid]
+        except KeyError:
+            return
+
         jstate = data.get ('job-state', cups.IPP_JOB_PROCESSING)
         s = int (jstate)
         if s == cups.IPP_JOB_PROCESSING:
@@ -2339,7 +2413,11 @@ class JobViewer (GtkGUI):
 
     def _set_job_status_text (self, column, cell, model, iter, *data):
         jobid = model.get_value (iter, 0)
-        data = self.jobs[jobid]
+        try:
+            data = self.jobs[jobid]
+        except KeyError:
+            return
+
         try:
             text = data['_status_text']
         except KeyError:
