@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2014 Red Hat, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -329,11 +329,12 @@ class Monitor(GObject.GObject):
                                reason)
 
     def get_notifications(self):
+        if self.update_timer:
+            GLib.source_remove (self.update_timer)
+
+        self.update_timer = None
         if not self.process_pending_events:
             # Defer the timer callback.
-            if self.update_timer:
-                GLib.source_remove (self.update_timer)
-
             self.update_timer = GLib.timeout_add (200,
                                                      self.get_notifications)
             debugprint ("Deferred get_notifications by 200ms")
@@ -488,9 +489,6 @@ class Monitor(GObject.GObject):
         # Update again when we're told to.  If we're getting CUPS
         # D-Bus signals, however, rely on those instead.
         if not self.received_any_dbus_signals:
-            if self.update_timer:
-                GLib.source_remove (self.update_timer)
-
             interval = notifications['notify-get-interval']
             t = GLib.timeout_add_seconds (interval,
                                           self.get_notifications)
@@ -537,6 +535,7 @@ class Monitor(GObject.GObject):
             pass
 
         events = ["printer-added",
+                  "printer-modified",
                   "printer-deleted",
                   "printer-state-changed"]
         if self.monitor_jobs:
@@ -559,6 +558,9 @@ class Monitor(GObject.GObject):
         cups.setUser (user)
 
         if self.sub_id != -1:
+            if self.update_timer:
+                GLib.source_remove (self.update_timer)
+
             self.update_timer = GLib.timeout_add_seconds (
                 MIN_REFRESH_INTERVAL,
                 self.get_notifications)
@@ -821,6 +823,9 @@ if __name__ == '__main__':
             print "*%s: cups connection error" % obj
 
         def on_cups_ipp_error (self, obj, err, errstring):
+            # cups.IPPError message is (utf-8) encoded
+            if isinstance(errstring, bytes):
+                    errstring = errstring.decode('utf-8', 'replace')
             print "*%s: IPP error (%d): %s" % (obj, err, errstring)
 
     set_debugging (True)
