@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2010, 2011, 2012 Red Hat, Inc.
+## Copyright (C) 2010, 2011, 2012, 2013 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -62,7 +62,7 @@ class PPDCache:
 
         try:
             f = self._cache[name]
-        except RuntimeError, e:
+        except RuntimeError as e:
             self._schedule_callback (callback, name, None, e)
             return
         except KeyError:
@@ -94,7 +94,7 @@ class PPDCache:
             ppd = cups.PPD (tmpfname)
             os.unlink (tmpfname)
             self._schedule_callback (callback, name, ppd, None)
-        except Exception, e:
+        except Exception as e:
             os.unlink (tmpfname)
             self._schedule_callback (callback, name, None, e)
 
@@ -182,14 +182,13 @@ if __name__ == "__main__":
     from debug import *
     from gi.repository import GObject
     set_debugging (True)
-    GObject.threads_init ()
     Gdk.threads_init ()
     loop = GObject.MainLoop ()
 
     def signal (name, result, exc):
         debugprint ("**** %s" % name)
-        debugprint (result)
-        debugprint (exc)
+        debugprint (repr (result))
+        debugprint (repr (exc))
 
     c = cups.Connection ()
     printers = c.getPrinters ()
