@@ -29,7 +29,9 @@ cups.require ("1.9.52")
 
 import asyncconn
 from debug import debugprint
-from gettext import gettext as _
+import config
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
 
 class PPDsLoader(GObject.GObject):
     """
@@ -84,8 +86,8 @@ class PPDsLoader(GObject.GObject):
         fmt = _("Searching")
         self._dialog = Gtk.MessageDialog (parent=parent,
                                           flags=Gtk.DialogFlags.MODAL |
-                                          Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                          type=Gtk.MessageType.INFO,
+                                                Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                          message_type=Gtk.MessageType.INFO,
                                           buttons=Gtk.ButtonsType.CANCEL,
                                           message_format=fmt)
 
@@ -221,8 +223,8 @@ class PPDsLoader(GObject.GObject):
                                          reply_handler=self._packagekit_reply,
                                          error_handler=self._packagekit_error,
                                          timeout=3600)
-        except Exception, e:
-            debugprint ("Failed to talk to PackageKit: %s" % e)
+        except Exception as e:
+            debugprint ("Failed to talk to PackageKit: %s" % repr (e))
             if self._dialog:
                 self._dialog.show_all ()
                 self._query_cups ()
@@ -235,7 +237,7 @@ class PPDsLoader(GObject.GObject):
             self._query_cups ()
 
     def _packagekit_error (self, exc):
-        debugprint ("Got PackageKit error: %s" % exc)
+        debugprint ("Got PackageKit error: %s" % repr (exc))
         if self._dialog:
             self._dialog.show_all ()
             self._query_cups ()
@@ -249,7 +251,7 @@ class PPDsLoader(GObject.GObject):
                                       reply_handler=self._jockey_reply,
                                       error_handler=self._jockey_error,
                                       timeout=3600)
-        except Exception, e:
+        except Exception as e:
             self._jockey_error (e)
 
     def _jockey_reply (self, conn, result):
@@ -262,7 +264,7 @@ class PPDsLoader(GObject.GObject):
         self._query_cups ()
 
     def _jockey_error (self, exc):
-        debugprint ("Got Jockey error: %s" % exc)
+        debugprint ("Got Jockey error: %s" % repr (exc))
         if self._need_requery_cups:
             self._query_cups ()
         else:
@@ -280,7 +282,7 @@ if __name__ == "__main__":
     class Foo:
         def __init__ (self):
             w = Gtk.Window ()
-            b = Gtk.Button ("Go")
+            b = Gtk.Button.new_with_label ("Go")
             w.add (b)
             b.connect ('clicked', self.go)
             w.connect ('delete-event', Gtk.main_quit)
@@ -306,6 +308,5 @@ if __name__ == "__main__":
 
     from debug import set_debugging
     set_debugging (True)
-    GObject.threads_init ()
     Foo ()
     Gtk.main ()
