@@ -2,7 +2,7 @@
 
 ## system-config-printer
 
-## Copyright (C) 2008, 2009, 2010, 2011, 2012 Red Hat, Inc.
+## Copyright (C) 2008, 2009, 2010, 2011, 2012, 2013 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -21,7 +21,8 @@
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import config
-from gettext import gettext as _
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
 import cups
 import dbus
 from gi.repository import GObject
@@ -133,7 +134,8 @@ class ServerSettings(GtkGUI):
         f = tempfile.TemporaryFile ()
         try:
             self.cupsconn.getFile (self.RESOURCE, file=f)
-        except cups.HTTPError, (s,):
+        except cups.HTTPError as e:
+            (s,) = e.args
             show_HTTP_Error (s, self._parent)
             raise
 
@@ -197,7 +199,8 @@ class ServerSettings(GtkGUI):
         self.cupsconn._begin_operation (_("fetching server settings"))
         try:
             self.server_settings = self.cupsconn.adminGetServerSettings()
-        except cups.IPPError, (e, m):
+        except cups.IPPError as e:
+            (e, m) = e.args
             show_IPP_Error(e, m, self._parent)
             self.cupsconn._end_operation ()
             raise
@@ -407,7 +410,8 @@ class ServerSettings(GtkGUI):
         f = tempfile.TemporaryFile ()
         try:
             self.cupsconn.getFile (self.RESOURCE, file=f)
-        except cups.HTTPError, (s,):
+        except cups.HTTPError as e:
+            (s,) = e.args
             show_HTTP_Error (s, self.dialog)
             return
 
@@ -486,7 +490,8 @@ class ServerSettings(GtkGUI):
         os.lseek (fd, 0, os.SEEK_SET)
         try:
             self.cupsconn.putFile ("/admin/conf/cupsd.conf", fd=fd)
-        except cups.HTTPError, (s,):
+        except cups.HTTPError as e:
+            (s,) = e.args
             show_HTTP_Error (s, self.dialog)
             return
 
@@ -514,11 +519,12 @@ class ServerSettings(GtkGUI):
         self.cupsconn._begin_operation (_("modifying server settings"))
         try:
             self.cupsconn.adminSetServerSettings(setting_dict)
-        except cups.IPPError, (e, m):
+        except cups.IPPError as e:
+            (e, m) = e.args
             show_IPP_Error(e, m, self.dialog)
             self.cupsconn._end_operation ()
             return True
-        except RuntimeError, s:
+        except RuntimeError as s:
             show_IPP_Error(None, s, self.dialog)
             self.cupsconn._end_operation ()
             return True
@@ -545,12 +551,12 @@ class ServerSettings(GtkGUI):
                     allowed = True
 
                 if not allowed:
-                    dialog = Gtk.MessageDialog (self.ServerSettingsDialog,
-                                                Gtk.DialogFlags.MODAL |
-                                                Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                                Gtk.MessageType.QUESTION,
-                                                Gtk.ButtonsType.NONE,
-                                                _("Adjust Firewall"))
+                    dialog = Gtk.MessageDialog (parent=self.ServerSettingsDialog,
+                                                flags=Gtk.DialogFlags.MODAL |
+                                                      Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                                message_type=Gtk.MessageType.QUESTION,
+                                                buttons=Gtk.ButtonsType.NONE,
+                                                message_format=_("Adjust Firewall"))
                     dialog.format_secondary_text (_("Adjust the firewall now "
                                                     "to allow all incoming IPP "
                                                     "connections?"))
