@@ -25,13 +25,14 @@ from gi.repository import Gdk
 from gi.repository import Gtk
 import subprocess
 import threading
-from gettext import gettext as _
+import config
+import gettext
+gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
 from debug import *
 
 # Initialise threading for D-Bus.  This is needed as long as it is
 # used from two separate threads.  We only do this in a few places
 # now, but in particular the troubleshooter does this (bug #662047).
-GObject.threads_init ()
 Gdk.threads_init ()
 dbus.mainloop.glib.threads_init ()
 
@@ -106,12 +107,12 @@ class TimedSubprocess(Timed):
 
     def show_wait_window (self):
         Gdk.threads_enter ()
-        wait = Gtk.MessageDialog (self.parent,
-                                  Gtk.DialogFlags.MODAL |
-                                  Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                  Gtk.MessageType.INFO,
-                                  Gtk.ButtonsType.CANCEL,
-                                  _("Please wait"))
+        wait = Gtk.MessageDialog (parent=self.parent,
+                                  flags=Gtk.DialogFlags.MODAL |
+                                        Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                  message_type=Gtk.MessageType.INFO,
+                                  buttons=Gtk.ButtonsType.CANCEL,
+                                  message_format=_("Please wait"))
         wait.connect ("delete_event", lambda *args: False)
         wait.connect ("response", self.wait_window_response)
         if self.parent:
@@ -150,7 +151,7 @@ class OperationThread(threading.Thread):
             debugprint ("Calling %s" % self.target)
             self.result = self.target (*self.args, **self.kwargs)
             debugprint ("Done")
-        except Exception, e:
+        except Exception as e:
             debugprint ("Caught exception %s" % e)
             self.exception = e
 
@@ -186,12 +187,12 @@ class TimedOperation(Timed):
             raise RuntimeError
 
         if self.show_dialog:
-            wait = Gtk.MessageDialog (self.parent,
-                                      Gtk.DialogFlags.MODAL |
-                                      Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                                      Gtk.MessageType.INFO,
-                                      Gtk.ButtonsType.CANCEL,
-                                      _("Please wait"))
+            wait = Gtk.MessageDialog (parent=self.parent,
+                                      flags=Gtk.DialogFlags.MODAL |
+                                            Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                      message_type=Gtk.MessageType.INFO,
+                                      buttons=Gtk.ButtonsType.CANCEL,
+                                      message_format=_("Please wait"))
             wait.connect ("delete_event", lambda *args: False)
             wait.connect ("response", self._wait_window_response)
             if self.parent:
