@@ -2,7 +2,7 @@
 
 ## Printing troubleshooter
 
-## Copyright (C) 2008, 2010 Red Hat, Inc.
+## Copyright (C) 2008, 2010, 2014 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 
@@ -20,29 +20,37 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+from gi.repository import Gtk
+
 import cups
 import os
 import tempfile
 import time
 from timedops import TimedOperation
 from base import *
+
+try:
+    from systemd import journal
+except:
+    journal = False
+
 class ErrorLogFetch(Question):
     def __init__ (self, troubleshooter):
         Question.__init__ (self, troubleshooter, "Error log fetch")
-        troubleshooter.new_page (gtk.Label (), self)
+        troubleshooter.new_page (Gtk.Label (), self)
         self.persistent_answers = {}
 
     def display (self):
         answers = self.troubleshooter.answers
         parent = self.troubleshooter.get_window ()
         self.answers = {}
-        try:
-            checkpoint = answers['error_log_checkpoint']
-        except KeyError:
-            checkpoint = None
+        checkpoint = answers.get ('error_log_checkpoint')
+        cursor = answers.get ('error_log_cursor')
 
-        if self.persistent_answers.has_key ('error_log'):
+        if (self.persistent_answers.has_key ('error_log') or
+            self.persistent_answers.has_key ('journal')):
             checkpoint = None
+            cursor = None
 
         def fetch_log (c):
             prompt = c._get_prompt_allowed ()
@@ -102,6 +110,23 @@ class ErrorLogFetch(Question):
             except cups.IPPError:
                 pass
 
+        self.answers = {}
+        if journal and cursor != None:
+            def journal_format (x):
+                try:
+                    priority = "XACEWNIDd"[x['PRIORITY']]
+                except (IndexError, TypeError):
+                    priority = " "
+
+                return (priority + " " +
+                        x['__REALTIME_TIMESTAMP'].strftime("[%m/%b/%Y:%T]") +
+                        " " + x['MESSAGE'])
+
+            r = journal.Reader ()
+            r.seek_cursor (cursor)
+            r.add_match (_COMM="cupsd")
+            self.answers['journal'] = map (journal_format, r)
+
         if checkpoint != None:
             self.op = TimedOperation (fetch_log,
                                       (self.authconn,),
@@ -112,8 +137,7 @@ class ErrorLogFetch(Question):
                 f.seek (checkpoint)
                 lines = f.readlines ()
                 os.remove (tmpfname)
-                self.answers = { 'error_log': map (lambda x: x.strip (),
-                                                   lines) }
+                self.answers['error_log'] = map (lambda x: x.strip (), lines)
 
         return False
 
