@@ -71,10 +71,10 @@ class PrintTestPage(Question):
         hbox.set_border_width (0)
         hbox.set_spacing (3)
         hbox.set_layout (Gtk.ButtonBoxStyle.START)
-        self.print_button = Gtk.Button (_("Print Test Page"))
+        self.print_button = Gtk.Button.new_with_label (_("Print Test Page"))
         hbox.pack_start (self.print_button, False, False, 0)
 
-        self.cancel_button = Gtk.Button (_("Cancel All Jobs"))
+        self.cancel_button = Gtk.Button.new_with_label (_("Cancel All Jobs"))
         hbox.pack_start (self.cancel_button, False, False, 0)
         page.pack_start (hbox, False, False, 0)
 
@@ -417,7 +417,10 @@ class PrintTestPage(Question):
             except RuntimeError:
                 self.persistent_answers['test_page_submit_failure'] = 'connect'
                 break
-            except cups.IPPError, (e, s):
+            except cups.IPPError as e:
+                (e, s) = e.args
+                if isinstance(s, bytes):
+                    s = s.decode('utf-8', 'replace')
                 if (e == cups.IPP_DOCUMENT_FORMAT and
                     mimetypes.index (mimetype) < (len (mimetypes) - 1)):
                     # Try next format.
@@ -444,7 +447,10 @@ class PrintTestPage(Question):
             for jobid in jobids:
                 try:
                     c.cancelJob (jobid)
-                except cups.IPPError, (e, s):
+                except cups.IPPError as e:
+                    (e, s) = e.args
+                    if isinstance(s, bytes):
+                        s = s.decode('utf-8', 'replace')
                     if e != cups.IPP_NOT_POSSIBLE:
                         self.persistent_answers['test_page_cancel_failure'] = (e, s)
 
